//[mahjong-utils](../../index.md)/[mahjongutils.hanhu](index.md)/[getParentPointByHanHu](get-parent-point-by-han-hu.md)

# getParentPointByHanHu

[common]\
fun [getParentPointByHanHu](get-parent-point-by-han-hu.md)(han: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html), hu: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [ParentPoint](-parent-point/index.md)

获取亲家（庄家）和牌点数

#### Return

亲家（庄家）和牌点数

#### Parameters

common

| | |
|---|---|
| han | 番数 |
| hu | 符数 |
